==> realestate-supervise-common-1.1.0-20230317.090001-34-sources.jar: cn/gtmap/realestate/supervise/entity/BaH.java <==
package cn.gtmap.realestate.supervise.entity;

import cn.gtmap.realestate.supervise.core.reflect.*;
import com.sun.istack.internal.Nullable;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.*;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:gaofeng@gtmap.cn">gaofeng</a>
 * @version 1.0，2017/6/15
 * @description 户属性结构
 */

@XmlAccessorType(XmlAccessType.FIELD)
@XmlRootElement
@XmlType
@Entity
@Table(
        name = "ba_h"
)
public class BaH implements Serializable {

    @XmlAttribute
    @Id
    @id
    private String id;

    @XmlAttribute
    private String bdcdyh;

    @XmlAttribute
    private String fwbm;

    @XmlAttribute
    private String ysdm;

    @XmlAttribute
    @Nullable
    private String zrzh;

    @XmlAttribute
    @Nullable
    private String ljzh;

    @XmlAttribute
    @Nullable
    private String ch;

    @XmlAttribute
    private String zl;

    @XmlAttribute
    private String mjdw;

    @XmlAttribute
    @Nullable
    private String sjcs;

    @XmlAttribute
    @Nullable
    private String hh;

    @XmlAttribute
    private String shbw;

    @XmlAttribute
    @Nullable
    private String hx;

    @XmlAttribute
    @Nullable
    private String hxjg;

    @XmlAttribute
    @Nullable
    private String fwyt1;

    @XmlAttribute
    @Nullable
    private String fwyt2;

    @XmlAttribute
    @Nullable
    private String fwyt3;

    @XmlAttribute
    @Nullable
    private String ycjzmj;

    @XmlAttribute
    @Nullable
    private String yctnjzmj;

    @XmlAttribute
    @Nullable
    private String ycftjzmj;

    @XmlAttribute
    @Nullable
    private String ycdxbfjzmj;

    @XmlAttribute
    @Nullable
    private String ycqtjzmj;

    @XmlAttribute
    @Nullable
    private String ycftxs;

    @XmlAttribute
    @Nullable
    private String scjzmj;

    @XmlAttribute
    @Nullable
    private String sctnjzmj;

    @XmlAttribute
    @Nullable
    private String scftjzmj;

    @XmlAttribute
    @Nullable
    private String scdxbfjzmj;

    @XmlAttribute
    @Nullable
    private String scqtjzmj;

    @XmlAttribute
    @Nullable
    private String scftxs;

    @XmlAttribute
    @Nullable
    private String gytdmj;

    @XmlAttribute
    @Nullable
    private String fttdmj;

    @XmlAttribute
    @Nullable
    private String dytdmj;

    @XmlAttribute
    @Nullable
    private String fwlx;

    @XmlAttribute
    @Nullable
    private String fwxz;

    @XmlAttribute
    @Nullable
    private String fcfht;

    @XmlAttribute
    private String zt;

    @XmlAttribute
    @qxdm
    private String qxdm;

    @Nullable
    private Date sjgxsj;

    @ywh
    private String ywh;

    @bwmc
    private String bwmc;

    @XmlAttribute
    private String zddm;

    @XmlAttribute
    private String zrzbsm;

    @XmlAttribute
    private String ytmc;

    @XmlAttribute
    private String pzyt;

    @XmlAttribute
    private String sjyt;

    @XmlAttribute
    private String fwlxmc;

    @XmlAttribute
    private String fwxzmc;

    public String getYtmc() {
        return ytmc;
    }

    public void setYtmc(String ytmc) {
        this.ytmc = ytmc;
    }

    public String getPzyt() {
        return pzyt;
    }

    public void setPzyt(String pzyt) {
        this.pzyt = pzyt;
    }

    public String getSjyt() {
        return sjyt;
    }

    public void setSjyt(String sjyt) {
        this.sjyt = sjyt;
    }

    public String getFwlxmc() {
        return fwlxmc;
    }

    public void setFwlxmc(String fwlxmc) {
        this.fwlxmc = fwlxmc;
    }

    public String getFwxzmc() {
        return fwxzmc;
    }

    public void setFwxzmc(String fwxzmc) {
        this.fwxzmc = fwxzmc;
    }

    public String getZddm() {
        return zddm;
    }

    public void setZddm(String zddm) {
        this.zddm = zddm;
    }

    public String getZrzbsm() {
        return zrzbsm;
    }

    public void setZrzbsm(String zrzbsm) {
        this.zrzbsm = zrzbsm;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getFwbm() {
        return fwbm;
    }

    public void setFwbm(String fwbm) {
        this.fwbm = fwbm;
    }

    public String getYsdm() {
        return ysdm;
    }

    public void setYsdm(String ysdm) {
        this.ysdm = ysdm;
    }

    public String getZrzh() {
        return zrzh;
    }

    public void setZrzh(String zrzh) {
        this.zrzh = zrzh;
    }

    public String getLjzh() {
        return ljzh;
    }

    public void setLjzh(String ljzh) {
        this.ljzh = ljzh;
    }

    public String getCh() {
        return ch;
    }

    public void setCh(String ch) {
        this.ch = ch;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getMjdw() {
        return mjdw;
    }

    public void setMjdw(String mjdw) {
        this.mjdw = mjdw;
    }

    public String getSjcs() {
        return sjcs;
    }

    public void setSjcs(String sjcs) {
        this.sjcs = sjcs;
    }

    public String getHh() {
        return hh;
    }

    public void setHh(String hh) {
        this.hh = hh;
    }

    public String getShbw() {
        return shbw;
    }

    public void setShbw(String shbw) {
        this.shbw = shbw;
    }

    public String getHx() {
        return hx;
    }

    public void setHx(String hx) {
        this.hx = hx;
    }

    public String getHxjg() {
        return hxjg;
    }

    public void setHxjg(String hxjg) {
        this.hxjg = hxjg;
    }

    public String getFwyt1() {
        return fwyt1;
    }

    public void setFwyt1(String fwyt1) {
        this.fwyt1 = fwyt1;
    }

    public String getFwyt2() {
        return fwyt2;
    }

    public void setFwyt2(String fwyt2) {
        this.fwyt2 = fwyt2;
    }

    public String getFwyt3() {
        return fwyt3;
    }

    public void setFwyt3(String fwyt3) {
        this.fwyt3 = fwyt3;
    }

    public String getYcjzmj() {
        return ycjzmj;
    }

    public void setYcjzmj(String ycjzmj) {
        this.ycjzmj = ycjzmj;
    }

    public String getYctnjzmj() {
        return yctnjzmj;
    }

    public void setYctnjzmj(String yctnjzmj) {
        this.yctnjzmj = yctnjzmj;
    }

    public String getYcftjzmj() {
        return ycftjzmj;
    }

    public void setYcftjzmj(String ycftjzmj) {
        this.ycftjzmj = ycftjzmj;
    }

    public String getYcdxbfjzmj() {
        return ycdxbfjzmj;
    }

    public void setYcdxbfjzmj(String ycdxbfjzmj) {
        this.ycdxbfjzmj = ycdxbfjzmj;
    }

    public String getYcqtjzmj() {
        return ycqtjzmj;
    }

    public void setYcqtjzmj(String ycqtjzmj) {
        this.ycqtjzmj = ycqtjzmj;
    }

    public String getYcftxs() {
        return ycftxs;
    }

    public void setYcftxs(String ycftxs) {
        this.ycftxs = ycftxs;
    }

    public String getScjzmj() {
        return scjzmj;
    }

    public void setScjzmj(String scjzmj) {
        this.scjzmj = scjzmj;
    }

    public String getSctnjzmj() {
        return sctnjzmj;
    }

    public void setSctnjzmj(String sctnjzmj) {
        this.sctnjzmj = sctnjzmj;
    }

    public String getScftjzmj() {
        return scftjzmj;
    }

    public void setScftjzmj(String scftjzmj) {
        this.scftjzmj = scftjzmj;
    }

    public String getScdxbfjzmj() {
        return scdxbfjzmj;
    }

    public void setScdxbfjzmj(String scdxbfjzmj) {
        this.scdxbfjzmj = scdxbfjzmj;
    }

    public String getScqtjzmj() {
        return scqtjzmj;
    }

    public void setScqtjzmj(String scqtjzmj) {
        this.scqtjzmj = scqtjzmj;
    }

    public String getScftxs() {
        return scftxs;
    }

    public void setScftxs(String scftxs) {
        this.scftxs = scftxs;
    }

    public String getGytdmj() {
        return gytdmj;
    }

    public void setGytdmj(String gytdmj) {
        this.gytdmj = gytdmj;
    }

    public String getFttdmj() {
        return fttdmj;
    }

    public void setFttdmj(String fttdmj) {
        this.fttdmj = fttdmj;
    }

    public String getDytdmj() {
        return dytdmj;
    }

    public void setDytdmj(String dytdmj) {
        this.dytdmj = dytdmj;
    }

    public String getFwlx() {
        return fwlx;
    }

    public void setFwlx(String fwlx) {
        this.fwlx = fwlx;
    }

    public String getFwxz() {
        return fwxz;
    }

    public void setFwxz(String fwxz) {
        this.fwxz = fwxz;
    }

    public String getFcfht() {
        return fcfht;
    }

    public void setFcfht(String fcfht) {
        this.fcfht = fcfht;
    }

    public String getZt() {
        return zt;
    }

    public void setZt(String zt) {
        this.zt = zt;
    }

    public String getQxdm() {
        return qxdm;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }

    public Date getSjgxsj() {
        return sjgxsj;
    }

    public void setSjgxsj(Date sjgxsj) {
        this.sjgxsj = sjgxsj;
    }

    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public String getBwmc() {
        return bwmc;
    }

    public void setBwmc(String bwmc) {
        this.bwmc = bwmc;
    }
}

==> realestate-supervise-common-1.1.0-20251204.005843-70-sources.jar: cn/gtmap/realestate/supervise/entity/BaH.java <==
package cn.gtmap.realestate.supervise.entity;

import cn.gtmap.realestate.supervise.core.reflect.*;
import com.sun.istack.internal.Nullable;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.*;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:gaofeng@gtmap.cn">gaofeng</a>
 * @version 1.0，2017/6/15
 * @description 户属性结构
 */

@XmlAccessorType(XmlAccessType.FIELD)
@XmlRootElement
@XmlType
@Entity
@Table(
        name = "ba_h"
)
public class BaH implements Serializable {

    @XmlAttribute
    @Id
    @id
    private String id;

    @XmlAttribute
    private String bdcdyh;

    @XmlAttribute
    private String fwbm;

    @XmlAttribute
    private String ysdm;

    @XmlAttribute
    @Nullable
    private String zrzh;

    @XmlAttribute
    @Nullable
    private String ljzh;

    @XmlAttribute
    @Nullable
    private String ch;

    @XmlAttribute
    private String zl;

    @XmlAttribute
    private String mjdw;

    @XmlAttribute
    @Nullable
    private String sjcs;

    @XmlAttribute
    @Nullable
    private String hh;

    @XmlAttribute
    private String shbw;

    @XmlAttribute
    @Nullable
    private String hx;

    @XmlAttribute
    @Nullable
    private String hxjg;

    @XmlAttribute
    @Nullable
    private String fwyt1;

    @XmlAttribute
    @Nullable
    private String fwyt2;

    @XmlAttribute
    @Nullable
    private String fwyt3;

    @XmlAttribute
    @Nullable
    private String ycjzmj;

    @XmlAttribute
    @Nullable
    private String yctnjzmj;

    @XmlAttribute
    @Nullable
    private String ycftjzmj;

    @XmlAttribute
    @Nullable
    private String ycdxbfjzmj;

    @XmlAttribute
    @Nullable
    private String ycqtjzmj;

    @XmlAttribute
    @Nullable
    private String ycftxs;

    @XmlAttribute
    @Nullable
    private String scjzmj;

    @XmlAttribute
    @Nullable
    private String sctnjzmj;

    @XmlAttribute
    @Nullable
    private String scftjzmj;

    @XmlAttribute
    @Nullable
    private String scdxbfjzmj;

    @XmlAttribute
    @Nullable
    private String scqtjzmj;

    @XmlAttribute
    @Nullable
    private String scftxs;

    @XmlAttribute
    @Nullable
    private String gytdmj;

    @XmlAttribute
    @Nullable
    private String fttdmj;

    @XmlAttribute
    @Nullable
    private String dytdmj;

    @XmlAttribute
    @Nullable
    private String fwlx;

    @XmlAttribute
    @Nullable
    private String fwxz;

    @XmlAttribute
    @Nullable
    private String fcfht;

    @XmlAttribute
    private String zt;

    @XmlAttribute
    @qxdm
    private String qxdm;

    @Nullable
    private Date sjgxsj;

    @ywh
    private String ywh;

    @bwmc
    private String bwmc;

    @XmlAttribute
    private String zddm;

    @XmlAttribute
    private String zrzbsm;

    @XmlAttribute
    private String ytmc;

    @XmlAttribute
    private String pzyt;

    @XmlAttribute
    private String sjyt;

    @XmlAttribute
    private String fwlxmc;

    @XmlAttribute
    private String fwxzmc;

    // ============73696 江苏省级_地籍数据监管模块总体需求新增字段开始===============

    /** 权利人/实际使用人 类型码 */
    @XmlAttribute
    private String qlrsjsyrlxm;

    /** 房产草图 */
    @XmlAttribute
    private String fcct;

    /** 朝向 */
    @XmlAttribute
    private String cx;

    /** 所在层 */
    @XmlAttribute
    private String szc;

    /** 房屋产权来源 */
    @XmlAttribute
    private String fwcqly;

    /** 墙体归属-东 */
    @XmlAttribute
    private String qtgsd;

    /** 墙体归属-南 */
    @XmlAttribute
    private String qtgsn;

    /** 墙体归属-西 */
    @XmlAttribute
    private String qtgsx;

    /** 墙体归属-北 */
    @XmlAttribute
    private String qtgsb;

    /** 有无电梯 */
    @XmlAttribute
    private String ywdt;

    /** 共有情况 */
    @XmlAttribute
    private String gyqk;

    /** 调查意见 */
    @XmlAttribute
    private String dcyj;

    /** 调查员 */
    @XmlAttribute
    private String dcy;

    /** 调查日期 */
    @XmlAttribute
    private Date dcrq;

    /** 审核意见 */
    @XmlAttribute
    private String shyj;

    /** 审核员 */
    @XmlAttribute
    private String shr;

    /** 审核日期 */
    @XmlAttribute
    private Date shrq;

    /** 房屋调查表 */
    @XmlAttribute
    private String fwdcb;

    /** 登记状态 */
    @XmlAttribute
    private String djzt;

    // ============73696 江苏省级_地籍数据监管模块总体需求新增字段结束===============

    public String getYtmc() {
        return ytmc;
    }

    public void setYtmc(String ytmc) {
        this.ytmc = ytmc;
    }

    public String getPzyt() {
        return pzyt;
    }

    public void setPzyt(String pzyt) {
        this.pzyt = pzyt;
    }

    public String getSjyt() {
        return sjyt;
    }

    public void setSjyt(String sjyt) {
        this.sjyt = sjyt;
    }

    public String getFwlxmc() {
        return fwlxmc;
    }

    public void setFwlxmc(String fwlxmc) {
        this.fwlxmc = fwlxmc;
    }

    public String getFwxzmc() {
        return fwxzmc;
    }

    public void setFwxzmc(String fwxzmc) {
        this.fwxzmc = fwxzmc;
    }

    public String getZddm() {
        return zddm;
    }

    public void setZddm(String zddm) {
        this.zddm = zddm;
    }

    public String getZrzbsm() {
        return zrzbsm;
    }

    public void setZrzbsm(String zrzbsm) {
        this.zrzbsm = zrzbsm;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getFwbm() {
        return fwbm;
    }

    public void setFwbm(String fwbm) {
        this.fwbm = fwbm;
    }

    public String getYsdm() {
        return ysdm;
    }

    public void setYsdm(String ysdm) {
        this.ysdm = ysdm;
    }

    public String getZrzh() {
        return zrzh;
    }

    public void setZrzh(String zrzh) {
        this.zrzh = zrzh;
    }

    public String getLjzh() {
        return ljzh;
    }

    public void setLjzh(String ljzh) {
        this.ljzh = ljzh;
    }

    public String getCh() {
        return ch;
    }

    public void setCh(String ch) {
        this.ch = ch;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getMjdw() {
        return mjdw;
    }

    public void setMjdw(String mjdw) {
        this.mjdw = mjdw;
    }

    public String getSjcs() {
        return sjcs;
    }

    public void setSjcs(String sjcs) {
        this.sjcs = sjcs;
    }

    public String getHh() {
        return hh;
    }

    public void setHh(String hh) {
        this.hh = hh;
    }

    public String getShbw() {
        return shbw;
    }

    public void setShbw(String shbw) {
        this.shbw = shbw;
    }

    public String getHx() {
        return hx;
    }

    public void setHx(String hx) {
        this.hx = hx;
    }

    public String getHxjg() {
        return hxjg;
    }

    public void setHxjg(String hxjg) {
        this.hxjg = hxjg;
    }

    public String getFwyt1() {
        return fwyt1;
    }

    public void setFwyt1(String fwyt1) {
        this.fwyt1 = fwyt1;
    }

    public String getFwyt2() {
        return fwyt2;
    }

    public void setFwyt2(String fwyt2) {
        this.fwyt2 = fwyt2;
    }

    public String getFwyt3() {
        return fwyt3;
    }

    public void setFwyt3(String fwyt3) {
        this.fwyt3 = fwyt3;
    }

    public String getYcjzmj() {
        return ycjzmj;
    }

    public void setYcjzmj(String ycjzmj) {
        this.ycjzmj = ycjzmj;
    }

    public String getYctnjzmj() {
        return yctnjzmj;
    }

    public void setYctnjzmj(String yctnjzmj) {
        this.yctnjzmj = yctnjzmj;
    }

    public String getYcftjzmj() {
        return ycftjzmj;
    }

    public void setYcftjzmj(String ycftjzmj) {
        this.ycftjzmj = ycftjzmj;
    }

    public String getYcdxbfjzmj() {
        return ycdxbfjzmj;
    }

    public void setYcdxbfjzmj(String ycdxbfjzmj) {
        this.ycdxbfjzmj = ycdxbfjzmj;
    }

    public String getYcqtjzmj() {
        return ycqtjzmj;
    }

    public void setYcqtjzmj(String ycqtjzmj) {
        this.ycqtjzmj = ycqtjzmj;
    }

    public String getYcftxs() {
        return ycftxs;
    }

    public void setYcftxs(String ycftxs) {
        this.ycftxs = ycftxs;
    }

    public String getScjzmj() {
        return scjzmj;
    }

    public void setScjzmj(String scjzmj) {
        this.scjzmj = scjzmj;
    }

    public String getSctnjzmj() {
        return sctnjzmj;
    }

    public void setSctnjzmj(String sctnjzmj) {
        this.sctnjzmj = sctnjzmj;
    }

    public String getScftjzmj() {
        return scftjzmj;
    }

    public void setScftjzmj(String scftjzmj) {
        this.scftjzmj = scftjzmj;
    }

    public String getScdxbfjzmj() {
        return scdxbfjzmj;
    }

    public void setScdxbfjzmj(String scdxbfjzmj) {
        this.scdxbfjzmj = scdxbfjzmj;
    }

    public String getScqtjzmj() {
        return scqtjzmj;
    }

    public void setScqtjzmj(String scqtjzmj) {
        this.scqtjzmj = scqtjzmj;
    }

    public String getScftxs() {
        return scftxs;
    }

    public void setScftxs(String scftxs) {
        this.scftxs = scftxs;
    }

    public String getGytdmj() {
        return gytdmj;
    }

    public void setGytdmj(String gytdmj) {
        this.gytdmj = gytdmj;
    }

    public String getFttdmj() {
        return fttdmj;
    }

    public void setFttdmj(String fttdmj) {
        this.fttdmj = fttdmj;
    }

    public String getDytdmj() {
        return dytdmj;
    }

    public void setDytdmj(String dytdmj) {
        this.dytdmj = dytdmj;
    }

    public String getFwlx() {
        return fwlx;
    }

    public void setFwlx(String fwlx) {
        this.fwlx = fwlx;
    }

    public String getFwxz() {
        return fwxz;
    }

    public void setFwxz(String fwxz) {
        this.fwxz = fwxz;
    }

    public String getFcfht() {
        return fcfht;
    }

    public void setFcfht(String fcfht) {
        this.fcfht = fcfht;
    }

    public String getZt() {
        return zt;
    }

    public void setZt(String zt) {
        this.zt = zt;
    }

    public String getQxdm() {
        return qxdm;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }

    public Date getSjgxsj() {
        return sjgxsj;
    }

    public void setSjgxsj(Date sjgxsj) {
        this.sjgxsj = sjgxsj;
    }

    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public String getBwmc() {
        return bwmc;
    }

    public void setBwmc(String bwmc) {
        this.bwmc = bwmc;
    }

    public String getQlrsjsyrlxm() {
        return qlrsjsyrlxm;
    }

    public void setQlrsjsyrlxm(String qlrsjsyrlxm) {
        this.qlrsjsyrlxm = qlrsjsyrlxm;
    }

    public String getFcct() {
        return fcct;
    }

    public void setFcct(String fcct) {
        this.fcct = fcct;
    }

    public String getCx() {
        return cx;
    }

    public void setCx(String cx) {
        this.cx = cx;
    }

    public String getSzc() {
        return szc;
    }

    public void setSzc(String szc) {
        this.szc = szc;
    }

    public String getFwcqly() {
        return fwcqly;
    }

    public void setFwcqly(String fwcqly) {
        this.fwcqly = fwcqly;
    }

    public String getQtgsd() {
        return qtgsd;
    }

    public void setQtgsd(String qtgsd) {
        this.qtgsd = qtgsd;
    }

    public String getQtgsn() {
        return qtgsn;
    }

    public void setQtgsn(String qtgsn) {
        this.qtgsn = qtgsn;
    }

    public String getQtgsx() {
        return qtgsx;
    }

    public void setQtgsx(String qtgsx) {
        this.qtgsx = qtgsx;
    }

    public String getQtgsb() {
        return qtgsb;
    }

    public void setQtgsb(String qtgsb) {
        this.qtgsb = qtgsb;
    }

    public String getYwdt() {
        return ywdt;
    }

    public void setYwdt(String ywdt) {
        this.ywdt = ywdt;
    }

    public String getGyqk() {
        return gyqk;
    }

    public void setGyqk(String gyqk) {
        this.gyqk = gyqk;
    }

    public String getDcyj() {
        return dcyj;
    }

    public void setDcyj(String dcyj) {
        this.dcyj = dcyj;
    }

    public String getDcy() {
        return dcy;
    }

    public void setDcy(String dcy) {
        this.dcy = dcy;
    }

    public Date getDcrq() {
        return dcrq;
    }

    public void setDcrq(Date dcrq) {
        this.dcrq = dcrq;
    }

    public String getShyj() {
        return shyj;
    }

    public void setShyj(String shyj) {
        this.shyj = shyj;
    }

    public String getShr() {
        return shr;
    }

    public void setShr(String shr) {
        this.shr = shr;
    }

    public Date getShrq() {
        return shrq;
    }

    public void setShrq(Date shrq) {
        this.shrq = shrq;
    }

    public String getFwdcb() {
        return fwdcb;
    }

    public void setFwdcb(String fwdcb) {
        this.fwdcb = fwdcb;
    }

    public String getDjzt() {
        return djzt;
    }

    public void setDjzt(String djzt) {
        this.djzt = djzt;
    }
}
